RescheduleCheckBuilder

Struct RescheduleCheckBuilder 

pub struct RescheduleCheckBuilder { /* private fields */ }
Builder for RescheduleCheck.

Implementations

Source

impl RescheduleCheckBuilder

pub fn next_check(&mut self, value: Option<OffsetDateTime>) -> &mut Self

the next check will be run at this time, if omitted the current time is used

pub fn force(&mut self, value: Option<bool>) -> &mut Self

Defaults to false. If enabled, the checks are executed regardless of time period restrictions and checks being disabled per object or on a global basis.

pub fn filter<VALUE: Into<IcingaFilter>>(&mut self, value: VALUE) -> &mut Self

filter to target which host and/or service check to reschedule

pub fn build(&self) -> Result<RescheduleCheck, Error>

Builds a new RescheduleCheck.

Errors

If a required field has not been initialized.

Source

impl RescheduleCheckBuilder

pub fn validate(&self) -> Result<(), Error>

makes sure the filter object type is valid for this call (either Host or Service)

Errors

this returns an error if the filter field object type is not Host or Service