ScheduleDowntimeBuilder

Struct ScheduleDowntimeBuilder 

pub struct ScheduleDowntimeBuilder { /* private fields */ }
Builder for ScheduleDowntime.

Implementations

Source

impl ScheduleDowntimeBuilder

pub fn author(&mut self, value: String) -> &mut Self

the author of the downtime

pub fn comment(&mut self, value: String) -> &mut Self

the body of the downtime comment

pub fn start_time(&mut self, value: OffsetDateTime) -> &mut Self

beginning of the downtime

pub fn end_time(&mut self, value: OffsetDateTime) -> &mut Self

end of the downtime

pub fn fixed(&mut self, value: Option<bool>) -> &mut Self

Defaults to true. If true, the downtime is fixed otherwise flexible.

pub fn duration(&mut self, value: Option<Duration>) -> &mut Self

the duration of the downtime

pub fn all_services(&mut self, value: Option<bool>) -> &mut Self

Sets downtime for all services for the matched host objects. If child_options are set, all child hosts and their services will schedule a downtime too. Defaults to false.

pub fn trigger_name(&mut self, value: Option<IcingaDowntimeName>) -> &mut Self

Sets the trigger for a triggered downtime.

pub fn child_options( &mut self, value: Option<IcingaDowntimeChildOptions>, ) -> &mut Self

Schedule child downtimes.

pub fn filter<VALUE: Into<IcingaFilter>>(&mut self, value: VALUE) -> &mut Self

filter to target which host and/or service to schedule a downtime for

pub fn build(&self) -> Result<ScheduleDowntime, Error>

Builds a new ScheduleDowntime.

Errors

If a required field has not been initialized.

Source

impl ScheduleDowntimeBuilder

pub fn validate(&self) -> Result<(), Error>

makes sure the filter object type is valid for this call (either Host or Service)

validates all_services is only used on host downtimes

validates duration is specified if fixed is set to false

Errors

this returns an error if the filter field object type is not Host or Service