deserialize_icinga_timestamp

Function deserialize_icinga_timestamp 

pub fn deserialize_icinga_timestamp<'de, D>(
    deserializer: D,
) -> Result<OffsetDateTime, D::Error>
where D: Deserializer<'de>,
deserializes a unix timestamp with sub second accuracy (usually 6 digits after the decimal point for icinga)

Errors

returns an error if the value can not be parsed as an f64 or if it can not be converted from a unix timestamp to a time::OffsetDateTime