pub trait IcingaJoinType { }Expand description
a marker trait for all the various join types for the different objects
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait IcingaJoinType { }a marker trait for all the various join types for the different objects
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".