structs related to the query metadata parameter and the result of queries including metadata
Structs
- Icinga
Metadata - metadata
Enums
- Icinga
Metadata Type - possible meta parameter values
structs related to the query metadata parameter and the result of queries including metadata