Enum icinga2_api::types::metadata::IcingaMetadataType
source · pub enum IcingaMetadataType {
UsedBy,
Location,
}Expand description
possible meta parameter values
Variants
UsedBy
includes information about the other icinga objects using each returned object
Location
includes information about the config file location of each returned object