Struct icinga2_api::types::names::IcingaHostGroupName
source · pub struct IcingaHostGroupName(pub String);Expand description
a host group name
Tuple Fields
0: StringTrait Implementations
sourceimpl Clone for IcingaHostGroupName
impl Clone for IcingaHostGroupName
sourcefn clone(&self) -> IcingaHostGroupName
fn clone(&self) -> IcingaHostGroupName
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for IcingaHostGroupName
impl Debug for IcingaHostGroupName
sourceimpl<'de> Deserialize<'de> for IcingaHostGroupName
impl<'de> Deserialize<'de> for IcingaHostGroupName
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Display for IcingaHostGroupName
impl Display for IcingaHostGroupName
sourceimpl FromStr for IcingaHostGroupName
impl FromStr for IcingaHostGroupName
sourceimpl Hash for IcingaHostGroupName
impl Hash for IcingaHostGroupName
sourceimpl Ord for IcingaHostGroupName
impl Ord for IcingaHostGroupName
sourcefn cmp(&self, other: &IcingaHostGroupName) -> Ordering
fn cmp(&self, other: &IcingaHostGroupName) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for IcingaHostGroupName
impl PartialEq for IcingaHostGroupName
sourcefn eq(&self, other: &IcingaHostGroupName) -> bool
fn eq(&self, other: &IcingaHostGroupName) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for IcingaHostGroupName
impl PartialOrd for IcingaHostGroupName
sourcefn partial_cmp(&self, other: &IcingaHostGroupName) -> Option<Ordering>
fn partial_cmp(&self, other: &IcingaHostGroupName) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for IcingaHostGroupName
impl Serialize for IcingaHostGroupName
impl Eq for IcingaHostGroupName
impl StructuralPartialEq for IcingaHostGroupName