Struct icinga2_api::types::names::IcingaHostName
source · pub struct IcingaHostName(pub String);Expand description
a host name
Tuple Fields
0: StringTrait Implementations
sourceimpl Clone for IcingaHostName
impl Clone for IcingaHostName
sourcefn clone(&self) -> IcingaHostName
fn clone(&self) -> IcingaHostName
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for IcingaHostName
impl Debug for IcingaHostName
sourceimpl<'de> Deserialize<'de> for IcingaHostName
impl<'de> Deserialize<'de> for IcingaHostName
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Display for IcingaHostName
impl Display for IcingaHostName
sourceimpl FromStr for IcingaHostName
impl FromStr for IcingaHostName
sourceimpl Hash for IcingaHostName
impl Hash for IcingaHostName
sourceimpl Ord for IcingaHostName
impl Ord for IcingaHostName
sourcefn cmp(&self, other: &IcingaHostName) -> Ordering
fn cmp(&self, other: &IcingaHostName) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for IcingaHostName
impl PartialEq for IcingaHostName
sourcefn eq(&self, other: &IcingaHostName) -> bool
fn eq(&self, other: &IcingaHostName) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for IcingaHostName
impl PartialOrd for IcingaHostName
sourcefn partial_cmp(&self, other: &IcingaHostName) -> Option<Ordering>
fn partial_cmp(&self, other: &IcingaHostName) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for IcingaHostName
impl Serialize for IcingaHostName
impl Eq for IcingaHostName
impl StructuralPartialEq for IcingaHostName