Struct icinga2_api::types::names::IcingaPackageName
source · pub struct IcingaPackageName(pub String);Expand description
a package name
Tuple Fields
0: StringTrait Implementations
sourceimpl Clone for IcingaPackageName
impl Clone for IcingaPackageName
sourcefn clone(&self) -> IcingaPackageName
fn clone(&self) -> IcingaPackageName
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for IcingaPackageName
impl Debug for IcingaPackageName
sourceimpl<'de> Deserialize<'de> for IcingaPackageName
impl<'de> Deserialize<'de> for IcingaPackageName
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Display for IcingaPackageName
impl Display for IcingaPackageName
sourceimpl FromStr for IcingaPackageName
impl FromStr for IcingaPackageName
sourceimpl Hash for IcingaPackageName
impl Hash for IcingaPackageName
sourceimpl Ord for IcingaPackageName
impl Ord for IcingaPackageName
sourcefn cmp(&self, other: &IcingaPackageName) -> Ordering
fn cmp(&self, other: &IcingaPackageName) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for IcingaPackageName
impl PartialEq for IcingaPackageName
sourcefn eq(&self, other: &IcingaPackageName) -> bool
fn eq(&self, other: &IcingaPackageName) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for IcingaPackageName
impl PartialOrd for IcingaPackageName
sourcefn partial_cmp(&self, other: &IcingaPackageName) -> Option<Ordering>
fn partial_cmp(&self, other: &IcingaPackageName) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for IcingaPackageName
impl Serialize for IcingaPackageName
impl Eq for IcingaPackageName
impl StructuralPartialEq for IcingaPackageName