Struct icinga2_api::types::names::IcingaTemplateName
source · pub struct IcingaTemplateName(pub String);Expand description
a template name
Tuple Fields
0: StringTrait Implementations
sourceimpl Clone for IcingaTemplateName
impl Clone for IcingaTemplateName
sourcefn clone(&self) -> IcingaTemplateName
fn clone(&self) -> IcingaTemplateName
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for IcingaTemplateName
impl Debug for IcingaTemplateName
sourceimpl<'de> Deserialize<'de> for IcingaTemplateName
impl<'de> Deserialize<'de> for IcingaTemplateName
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Display for IcingaTemplateName
impl Display for IcingaTemplateName
sourceimpl FromStr for IcingaTemplateName
impl FromStr for IcingaTemplateName
sourceimpl Hash for IcingaTemplateName
impl Hash for IcingaTemplateName
sourceimpl Ord for IcingaTemplateName
impl Ord for IcingaTemplateName
sourcefn cmp(&self, other: &IcingaTemplateName) -> Ordering
fn cmp(&self, other: &IcingaTemplateName) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for IcingaTemplateName
impl PartialEq for IcingaTemplateName
sourcefn eq(&self, other: &IcingaTemplateName) -> bool
fn eq(&self, other: &IcingaTemplateName) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for IcingaTemplateName
impl PartialOrd for IcingaTemplateName
sourcefn partial_cmp(&self, other: &IcingaTemplateName) -> Option<Ordering>
fn partial_cmp(&self, other: &IcingaTemplateName) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for IcingaTemplateName
impl Serialize for IcingaTemplateName
impl Eq for IcingaTemplateName
impl StructuralPartialEq for IcingaTemplateName