Struct icinga2_api::types::names::IcingaUserGroupName
source · pub struct IcingaUserGroupName(pub String);Expand description
a user group name
Tuple Fields
0: StringTrait Implementations
sourceimpl Clone for IcingaUserGroupName
impl Clone for IcingaUserGroupName
sourcefn clone(&self) -> IcingaUserGroupName
fn clone(&self) -> IcingaUserGroupName
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for IcingaUserGroupName
impl Debug for IcingaUserGroupName
sourceimpl<'de> Deserialize<'de> for IcingaUserGroupName
impl<'de> Deserialize<'de> for IcingaUserGroupName
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Display for IcingaUserGroupName
impl Display for IcingaUserGroupName
sourceimpl FromStr for IcingaUserGroupName
impl FromStr for IcingaUserGroupName
sourceimpl Hash for IcingaUserGroupName
impl Hash for IcingaUserGroupName
sourceimpl Ord for IcingaUserGroupName
impl Ord for IcingaUserGroupName
sourcefn cmp(&self, other: &IcingaUserGroupName) -> Ordering
fn cmp(&self, other: &IcingaUserGroupName) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for IcingaUserGroupName
impl PartialEq for IcingaUserGroupName
sourcefn eq(&self, other: &IcingaUserGroupName) -> bool
fn eq(&self, other: &IcingaUserGroupName) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for IcingaUserGroupName
impl PartialOrd for IcingaUserGroupName
sourcefn partial_cmp(&self, other: &IcingaUserGroupName) -> Option<Ordering>
fn partial_cmp(&self, other: &IcingaUserGroupName) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for IcingaUserGroupName
impl Serialize for IcingaUserGroupName
impl Eq for IcingaUserGroupName
impl StructuralPartialEq for IcingaUserGroupName