Rest API request related types
(as opposed to the streaming event long-polling API parts)
Traits
- a trait for objects describing a REST API endpoint
- this is a marker trait that marks a type as a valid response type for a given RestApiEndpoint